##
##  inetutils.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         inetutils
Summary:      GNU Internet Utilities
URL:          http://www.gnu.org/software/inetutils/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Networking
License:      GPL
Version:      2.5
Release:      20231230

#   package options
%option       with_legacy  no

#   list of sources
Source0:      http://ftp.gnu.org/gnu/inetutils/inetutils-%{version}.tar.gz
Patch0:       inetutils.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  ncurses
PreReq:       ncurses

%description
    The GNU Internet Utilities are a collection of common network
    programs. Please note that specific to this OpenPKG version only a
    subset of the original GNU Internet Utilities is provided. Mainly we
    provide networking clients only.

%track
    prog inetutils = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/inetutils/
        regex     = inetutils-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags ncurses .}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --program-prefix=g \
        --disable-servers \
        --disable-whois \
        --disable-libls \
        --disable-encryption \
        --disable-authentication \
        --without-krb4 \
        --without-krb5 \
        --without-wrap \
        --without-pam
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/charset.alias
    for i in tftp syslog.conf ftpd inetd rexecd rlogind rshd syslogd talkd \
        telnetd tftpd; do
        rm -f $RPM_BUILD_ROOT%{l_prefix}/man/man?/g$i.?
    done
%if "%{with_legacy}" == "yes"
    for d in $RPM_BUILD_ROOT%{l_prefix}/{bin,man/man?}; do
        for i in $d/*; do
            [ -f $i ] || continue
            source=`echo "$i" | sed -n -e 's;^.*/\([^/]\{1,\}\)$;\1;p'`
            target=`echo "$i" | sed -n -e 's;^\(.*/\)g\([^/]\{1,\}\)$;\1\2;p'`
            ln -s $source $target
        done
    done
%endif
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%attr(4711,%{l_susr},%{l_sgrp}) %{l_prefix}/bin/gping' \
        '%attr(4711,%{l_susr},%{l_sgrp}) %{l_prefix}/bin/grcp' \
        '%attr(4711,%{l_susr},%{l_sgrp}) %{l_prefix}/bin/grlogin' \
        '%attr(4711,%{l_susr},%{l_sgrp}) %{l_prefix}/bin/grsh'

%files -f files

%clean

